Breezy Release Notes — Breezy 3.0.2dev documentation

Table of Contents (3.0.2dev)

# Breezy Release Notes

## brz ?.?.?

Codename

  Nirvana

2.x.y

  NOT RELEASED YET

### External Compatibility Breaks

### New Features

### Improvements

### Bug Fixes

### Documentation

### API Changes

### Internals

### Testing

### Table of Contents

- What’s New in Breezy 3.0?
- Breezy User Guide
- Tutorials
- Quick Reference
- Breezy Release Notes
- Breezy Upgrade Guide
- Breezy User Reference
- Breezy System Administrator’s Guide

Show Source